# TxColor
TxColor is the python library that provides text color formating.

TxColor gives you the ability to format text with colors right in it! You can also provide a string and it will look like this: <r>red</r>.

Color tags: 
r - red
g - green
B - blue
y - yellow
p - purple
c - cyan
w - white
Color tags may update in future!